#ifndef BPSMPlayerConfig_h
#define BPSMPlayerConfig_h

#import <Foundation/Foundation.h>
#import "BPSMAdvertisement.h"

//! Bradmax player configuration object.
@interface BPSMPlayerConfig : NSObject

//! URL pointing to json file with media data.
@property NSString *dataSource;

//! Array of BPSMMedia objects.
@property NSMutableArray *dataProvider;

//! Configuration object for player advertisement.
@property BPSMAdvertisement *advertisement;

//! BOOL - Indicates if player should play video after player load.
@property NSNumber *autoplay;

//! BOOL - Indicates if player should start playback with muted sound.
@property NSNumber *mute;

//! Indicates initial start time of video.
@property NSNumber *startTime;

//! BOOL - Indicates if quality selection should be enabled in player.
@property NSNumber *qualitySelectionEnabled;

//! Selects if bitrate or resolution should be on quality list.
@property NSString *qualityLabelType;

//! BOOL - Indicates if player skin should be visible at player start.
@property NSNumber *showSkinOnInit;

//! List of comma separated social button names.
@property NSString *shareButtons;

//! List of comma separated elements names to hide in player.
//! Currently only: “fullscreenButton” support this feature.
@property NSString *hideUIElements;

//! Name of end splash view to use.
@property NSString *endSplash;

//! Default subtitles language in ISO 3166-1 language code.
@property NSString *subtitles;

//! Head constraint for DVR window for live streams.
@property NSNumber *dvrWindowStartTime;

//! Tail constraint for DVR window for live streams.
@property NSNumber *dvrWindowEndTime;

//! BOOL - This option indicates if video should be inlined for iPhone devices. By default for iPhones devices video is fullscreened with native iOS player.
@property NSNumber *iosInlineVideo;

- (NSDictionary *) toNSDictionary;

@end

#endif /* BPSMPlayerConfig_h */
